@@ -1,10 +1,11 @@
 from pandas.api.types import is_numeric_dtype
 from grplot.features.sep.tick_sep.tick_sep_def import tick_sep_def
+from grplot.utils.first_valid_index import first_valid_index
 
 
 def tick_sep_data_def(df, ax, axis, axislabel, sep):
     if axislabel in df:
-        if (is_numeric_dtype(df[axislabel]) == True) or (is_numeric_dtype(type(df[axislabel][0])) == True):
+        if (is_numeric_dtype(df[axislabel]) == True) or (is_numeric_dtype(type(df[axislabel][first_valid_index(df)])) == True):
             tick_sep_def(ax=ax, axis=axis, sep=sep)
         else:
             pass
